# Emojis

100
1234
8ball
a
ab
abc
abcd
accept
aerial_tramway
airplane
airplane_arriving
airplane_departure
airplane_small
alarm_clock
alembic
alien
ambulance
amphora
anchor
angel
angel_tone1
angel_tone2
angel_tone3
angel_tone4
angel_tone5
anger
anger_right
angry
anguished
ant
apple
aquarius
aries
arrow_backward
arrow_double_down
arrow_double_up
arrow_down
arrow_down_small
arrow_forward
arrow_heading_down
arrow_heading_up
arrow_left
arrow_lower_left
arrow_lower_right
arrow_right
arrow_right_hook
arrow_up
arrow_up_down
arrow_up_small
arrow_upper_left
arrow_upper_right
arrows_clockwise
arrows_counterclockwise
art
articulated_lorry
asterisk
astonished
athletic_shoe
atm
atom
avocado
b
baby
baby_bottle
baby_chick
baby_symbol
baby_tone1
baby_tone2
baby_tone3
baby_tone4
baby_tone5
back
bacon
badminton
baggage_claim
balloon
ballot_box
ballot_box_with_check
bamboo
banana
bangbang
bank
bar_chart
barber
baseball
basketball
basketball_player
basketball_player_tone1
basketball_player_tone2
basketball_player_tone3
basketball_player_tone4
basketball_player_tone5
bat
bath
bath_tone1
bath_tone2
bath_tone3
bath_tone4
bath_tone5
bathtub
battery
beach
beach_umbrella
bear
bed
bee
beer
beers
beetle
beginner
bell
bellhop
bento
bicyclist
bicyclist_tone1
bicyclist_tone2
bicyclist_tone3
bicyclist_tone4
bicyclist_tone5
bike
bikini
biohazard
bird
birthday
black_circle
black_heart
black_joker
black_large_square
black_medium_small_square
black_medium_square
black_nib
black_small_square
black_square_button
blossom
blowfish
blue_book
blue_car
blue_circle
blue_heart
blush
boar
bomb
book
bookmark
bookmark_tabs
books
boom
boot
bouquet
bow
bow_and_arrow
bow_tone1
bow_tone2
bow_tone3
bow_tone4
bow_tone5
bowling
boxing_glove
boy
boy_tone1
boy_tone2
boy_tone3
boy_tone4
boy_tone5
bread
bride_with_veil
bride_with_veil_tone1
bride_with_veil_tone2
bride_with_veil_tone3
bride_with_veil_tone4
bride_with_veil_tone5
bridge_at_night
briefcase
broken_heart
bug
bulb
bullettrain_front
bullettrain_side
burrito
bus
busstop
bust_in_silhouette
busts_in_silhouette
butterfly
cactus
cake
calendar
calendar_spiral
call_me
call_me_tone1
call_me_tone2
call_me_tone3
call_me_tone4
call_me_tone5
calling
camel
camera
camera_with_flash
camping
cancer
candle
candy
canoe
capital_abcd
capricorn
card_box
card_index
carousel_horse
carrot
cartwheel
cartwheel_tone1
cartwheel_tone2
cartwheel_tone3
cartwheel_tone4
cartwheel_tone5
cat2
cat
cd
chains
champagne
champagne_glass
chart
chart_with_downwards_trend
chart_with_upwards_trend
checkered_flag
cheese
cherries
cherry_blossom
chestnut
chicken
children_crossing
chipmunk
chocolate_bar
christmas_tree
church
cinema
circus_tent
city_dusk
city_sunset
cityscape
cl
clap
clap_tone1
clap_tone2
clap_tone3
clap_tone4
clap_tone5
clapper
classical_building
clipboard
clock1030
clock10
clock1130
clock11
clock1230
clock12
clock130
clock1
clock230
clock2
clock330
clock3
clock430
clock4
clock530
clock5
clock630
clock6
clock730
clock7
clock830
clock8
clock930
clock9
clock
closed_book
closed_lock_with_key
closed_umbrella
cloud
cloud_lightning
cloud_rain
cloud_snow
cloud_tornado
clown
clubs
cocktail
coffee
coffin
cold_sweat
comet
compression
computer
confetti_ball
confounded
confused
congratulations
construction
construction_site
construction_worker
construction_worker_tone1
construction_worker_tone2
construction_worker_tone3
construction_worker_tone4
construction_worker_tone5
control_knobs
convenience_store
cookie
cooking
cool
cop
cop_tone1
cop_tone2
cop_tone3
cop_tone4
cop_tone5
copyright
corn
couch
couple
couple_mm
couple_with_heart
couple_ww
couplekiss
cow2
cow
cowboy
crab
crayon
credit_card
crescent_moon
cricket
crocodile
croissant
cross
crossed_flags
crossed_swords
crown
cruise_ship
cry
crying_cat_face
crystal_ball
cucumber
cupid
curly_loop
currency_exchange
curry
custard
customs
cyclone
dagger
dancer
dancer_tone1
dancer_tone2
dancer_tone3
dancer_tone4
dancer_tone5
dancers
dango
dark_sunglasses
dart
dash
date
deciduous_tree
deer
department_store
desert
desktop
diamond_shape_with_a_dot_inside
diamonds
disappointed
disappointed_relieved
dividers
dizzy
dizzy_face
do_not_litter
dog2
dog
dollar
dolls
dolphin
door
doughnut
dove
dragon
dragon_face
dress
dromedary_camel
drooling_face
droplet
drum
duck
dvd
e-mail
eagle
ear
ear_of_rice
ear_tone1
ear_tone2
ear_tone3
ear_tone4
ear_tone5
earth_africa
earth_americas
earth_asia
egg
eggplant
eight
eight_pointed_black_star
eight_spoked_asterisk
eject
electric_plug
elephant
end
envelope
envelope_with_arrow
euro
european_castle
european_post_office
evergreen_tree
exclamation
expressionless
eye
eye_in_speech_bubble
eyeglasses
eyes
face_palm
face_palm_tone1
face_palm_tone2
face_palm_tone3
face_palm_tone4
face_palm_tone5
factory
fallen_leaf
family
family_mmb
family_mmbb
family_mmg
family_mmgb
family_mmgg
family_mwbb
family_mwg
family_mwgb
family_mwgg
family_wwb
family_wwbb
family_wwg
family_wwgb
family_wwgg
fast_forward
fax
fearful
feet
fencer
ferris_wheel
ferry
field_hockey
file_cabinet
file_folder
film_frames
fingers_crossed
fingers_crossed_tone1
fingers_crossed_tone2
fingers_crossed_tone3
fingers_crossed_tone4
fingers_crossed_tone5
fire
fire_engine
fireworks
first_place
first_quarter_moon
first_quarter_moon_with_face
fish
fish_cake
fishing_pole_and_fish
fist
fist_tone1
fist_tone2
fist_tone3
fist_tone4
fist_tone5
five
flag_ac
flag_ad
flag_ae
flag_af
flag_ag
flag_ai
flag_al
flag_am
flag_ao
flag_aq
flag_ar
flag_as
flag_at
flag_au
flag_aw
flag_ax
flag_az
flag_ba
flag_bb
flag_bd
flag_be
flag_bf
flag_bg
flag_bh
flag_bi
flag_bj
flag_bl
flag_black
flag_bm
flag_bn
flag_bo
flag_bq
flag_br
flag_bs
flag_bt
flag_bv
flag_bw
flag_by
flag_bz
flag_ca
flag_cc
flag_cd
flag_cf
flag_cg
flag_ch
flag_ci
flag_ck
flag_cl
flag_cm
flag_cn
flag_co
flag_cp
flag_cr
flag_cu
flag_cv
flag_cw
flag_cx
flag_cy
flag_cz
flag_de
flag_dg
flag_dj
flag_dk
flag_dm
flag_do
flag_dz
flag_ea
flag_ec
flag_ee
flag_eg
flag_eh
flag_er
flag_es
flag_et
flag_eu
flag_fi
flag_fj
flag_fk
flag_fm
flag_fo
flag_fr
flag_ga
flag_gb
flag_gd
flag_ge
flag_gf
flag_gg
flag_gh
flag_gi
flag_gl
flag_gm
flag_gn
flag_gp
flag_gq
flag_gr
flag_gs
flag_gt
flag_gu
flag_gw
flag_gy
flag_hk
flag_hm
flag_hn
flag_hr
flag_ht
flag_hu
flag_ic
flag_id
flag_ie
flag_il
flag_im
flag_in
flag_io
flag_iq
flag_ir
flag_is
flag_it
flag_je
flag_jm
flag_jo
flag_jp
flag_ke
flag_kg
flag_kh
flag_ki
flag_km
flag_kn
flag_kp
flag_kr
flag_kw
flag_ky
flag_kz
flag_la
flag_lb
flag_lc
flag_li
flag_lk
flag_lr
flag_ls
flag_lt
flag_lu
flag_lv
flag_ly
flag_ma
flag_mc
flag_md
flag_me
flag_mf
flag_mg
flag_mh
flag_mk
flag_ml
flag_mm
flag_mn
flag_mo
flag_mp
flag_mq
flag_mr
flag_ms
flag_mt
flag_mu
flag_mv
flag_mw
flag_mx
flag_my
flag_mz
flag_na
flag_nc
flag_ne
flag_nf
flag_ng
flag_ni
flag_nl
flag_no
flag_np
flag_nr
flag_nu
flag_nz
flag_om
flag_pa
flag_pe
flag_pf
flag_pg
flag_ph
flag_pk
flag_pl
flag_pm
flag_pn
flag_pr
flag_ps
flag_pt
flag_pw
flag_py
flag_qa
flag_re
flag_ro
flag_rs
flag_ru
flag_rw
flag_sa
flag_sb
flag_sc
flag_sd
flag_se
flag_sg
flag_sh
flag_si
flag_sj
flag_sk
flag_sl
flag_sm
flag_sn
flag_so
flag_sr
flag_ss
flag_st
flag_sv
flag_sx
flag_sy
flag_sz
flag_ta
flag_tc
flag_td
flag_tf
flag_tg
flag_th
flag_tj
flag_tk
flag_tl
flag_tm
flag_tn
flag_to
flag_tr
flag_tt
flag_tv
flag_tw
flag_tz
flag_ua
flag_ug
flag_um
flag_us
flag_uy
flag_uz
flag_va
flag_vc
flag_ve
flag_vg
flag_vi
flag_vn
flag_vu
flag_wf
flag_white
flag_ws
flag_xk
flag_ye
flag_yt
flag_za
flag_zm
flag_zw
flags
flashlight
fleur-de-lis
floppy_disk
flower_playing_cards
flushed
fog
foggy
football
footprints
fork_and_knife
fork_knife_plate
fountain
four
four_leaf_clover
fox
frame_photo
free
french_bread
fried_shrimp
fries
frog
frowning2
frowning
fuelpump
full_moon
full_moon_with_face
game_die
gear
gem
gemini
ghost
gift
gift_heart
girl
girl_tone1
girl_tone2
girl_tone3
girl_tone4
girl_tone5
globe_with_meridians
goal
goat
golf
golfer
gorilla
grapes
green_apple
green_book
green_heart
grey_exclamation
grey_question
grimacing
grin
grinning
guardsman
guardsman_tone1
guardsman_tone2
guardsman_tone3
guardsman_tone4
guardsman_tone5
guitar
gun
haircut
haircut_tone1
haircut_tone2
haircut_tone3
haircut_tone4
haircut_tone5
hamburger
hammer
hammer_pick
hamster
hand_splayed
hand_splayed_tone1
hand_splayed_tone2
hand_splayed_tone3
hand_splayed_tone4
hand_splayed_tone5
handbag
handball
handball_tone1
handball_tone2
handball_tone3
handball_tone4
handball_tone5
handshake
handshake_tone1
handshake_tone2
handshake_tone3
handshake_tone4
handshake_tone5
hash
hatched_chick
hatching_chick
head_bandage
headphones
hear_no_evil
heart
heart_decoration
heart_exclamation
heart_eyes
heart_eyes_cat
heartbeat
heartpulse
hearts
heavy_check_mark
heavy_division_sign
heavy_dollar_sign
heavy_minus_sign
heavy_multiplication_x
heavy_plus_sign
helicopter
helmet_with_cross
herb
hibiscus
high_brightness
high_heel
hockey
hole
homes
honey_pot
horse
horse_racing
horse_racing_tone1
horse_racing_tone2
horse_racing_tone3
horse_racing_tone4
horse_racing_tone5
hospital
hot_pepper
hotdog
hotel
hotsprings
hourglass
hourglass_flowing_sand
house
house_abandoned
house_with_garden
hugging
hushed
ice_cream
ice_skate
icecream
id
ideograph_advantage
imp
inbox_tray
incoming_envelope
information_desk_person
information_desk_person_tone1
information_desk_person_tone2
information_desk_person_tone3
information_desk_person_tone4
information_desk_person_tone5
information_source
innocent
interrobang
iphone
island
izakaya_lantern
jack_o_lantern
japan
japanese_castle
japanese_goblin
japanese_ogre
jeans
joy
joy_cat
joystick
juggling
juggling_tone1
juggling_tone2
juggling_tone3
juggling_tone4
juggling_tone5
kaaba
key2
key
keyboard
keycap_ten
kimono
kiss
kiss_mm
kiss_ww
kissing
kissing_cat
kissing_closed_eyes
kissing_heart
kissing_smiling_eyes
kiwi
knife
koala
koko
label
large_blue_diamond
large_orange_diamond
last_quarter_moon
last_quarter_moon_with_face
laughing
leaves
ledger
left_facing_fist
left_facing_fist_tone1
left_facing_fist_tone2
left_facing_fist_tone3
left_facing_fist_tone4
left_facing_fist_tone5
left_luggage
left_right_arrow
leftwards_arrow_with_hook
lemon
leo
leopard
level_slider
levitate
libra
lifter
lifter_tone1
lifter_tone2
lifter_tone3
lifter_tone4
lifter_tone5
light_rail
link
lion_face
lips
lipstick
lizard
lock
lock_with_ink_pen
lollipop
loop
loud_sound
loudspeaker
love_hotel
love_letter
low_brightness
lying_face
m
mag
mag_right
mahjong
mailbox
mailbox_closed
mailbox_with_mail
mailbox_with_no_mail
man
man_dancing
man_dancing_tone1
man_dancing_tone2
man_dancing_tone3
man_dancing_tone4
man_dancing_tone5
man_in_tuxedo
man_in_tuxedo_tone1
man_in_tuxedo_tone2
man_in_tuxedo_tone3
man_in_tuxedo_tone4
man_in_tuxedo_tone5
man_tone1
man_tone2
man_tone3
man_tone4
man_tone5
man_with_gua_pi_mao
man_with_gua_pi_mao_tone1
man_with_gua_pi_mao_tone2
man_with_gua_pi_mao_tone3
man_with_gua_pi_mao_tone4
man_with_gua_pi_mao_tone5
man_with_turban
man_with_turban_tone1
man_with_turban_tone2
man_with_turban_tone3
man_with_turban_tone4
man_with_turban_tone5
mans_shoe
map
maple_leaf
martial_arts_uniform
mask
massage
massage_tone1
massage_tone2
massage_tone3
massage_tone4
massage_tone5
meat_on_bone
medal
mega
melon
menorah
mens
metal
metal_tone1
metal_tone2
metal_tone3
metal_tone4
metal_tone5
metro
microphone2
microphone
microscope
middle_finger
middle_finger_tone1
middle_finger_tone2
middle_finger_tone3
middle_finger_tone4
middle_finger_tone5
military_medal
milk
milky_way
minibus
minidisc
mobile_phone_off
money_mouth
money_with_wings
moneybag
monkey
monkey_face
monorail
mortar_board
mosque
motor_scooter
motorboat
motorcycle
motorway
mount_fuji
mountain
mountain_bicyclist
mountain_bicyclist_tone1
mountain_bicyclist_tone2
mountain_bicyclist_tone3
mountain_bicyclist_tone4
mountain_bicyclist_tone5
mountain_cableway
mountain_railway
mountain_snow
mouse2
mouse
mouse_three_button
movie_camera
moyai
mrs_claus
mrs_claus_tone1
mrs_claus_tone2
mrs_claus_tone3
mrs_claus_tone4
mrs_claus_tone5
muscle
muscle_tone1
muscle_tone2
muscle_tone3
muscle_tone4
muscle_tone5
mushroom
musical_keyboard
musical_note
musical_score
mute
nail_care
nail_care_tone1
nail_care_tone2
nail_care_tone3
nail_care_tone4
nail_care_tone5
name_badge
nauseated_face
necktie
negative_squared_cross_mark
nerd
neutral_face
new
new_moon
new_moon_with_face
newspaper2
newspaper
ng
night_with_stars
nine
no_bell
no_bicycles
no_entry
no_entry_sign
no_good
no_good_tone1
no_good_tone2
no_good_tone3
no_good_tone4
no_good_tone5
no_mobile_phones
no_mouth
no_pedestrians
no_smoking
non-potable_water
nose
nose_tone1
nose_tone2
nose_tone3
nose_tone4
nose_tone5
notebook
notebook_with_decorative_cover
notepad_spiral
notes
nut_and_bolt
o2
o
ocean
octagonal_sign
octopus
oden
office
oil
ok
ok_hand
ok_hand_tone1
ok_hand_tone2
ok_hand_tone3
ok_hand_tone4
ok_hand_tone5
ok_woman
ok_woman_tone1
ok_woman_tone2
ok_woman_tone3
ok_woman_tone4
ok_woman_tone5
older_man
older_man_tone1
older_man_tone2
older_man_tone3
older_man_tone4
older_man_tone5
older_woman
older_woman_tone1
older_woman_tone2
older_woman_tone3
older_woman_tone4
older_woman_tone5
om_symbol
on
oncoming_automobile
oncoming_bus
oncoming_police_car
oncoming_taxi
one
open_file_folder
open_hands
open_hands_tone1
open_hands_tone2
open_hands_tone3
open_hands_tone4
open_hands_tone5
open_mouth
ophiuchus
orange_book
orthodox_cross
outbox_tray
owl
ox
package
page_facing_up
page_with_curl
pager
paintbrush
palm_tree
pancakes
panda_face
paperclip
paperclips
park
parking
part_alternation_mark
partly_sunny
passport_control
pause_button
peace
peach
peanuts
pear
pen_ballpoint
pen_fountain
pencil2
pencil
penguin
pensive
performing_arts
persevere
person_frowning
person_frowning_tone1
person_frowning_tone2
person_frowning_tone3
person_frowning_tone4
person_frowning_tone5
person_with_blond_hair
person_with_blond_hair_tone1
person_with_blond_hair_tone2
person_with_blond_hair_tone3
person_with_blond_hair_tone4
person_with_blond_hair_tone5
person_with_pouting_face
person_with_pouting_face_tone1
person_with_pouting_face_tone2
person_with_pouting_face_tone3
person_with_pouting_face_tone4
person_with_pouting_face_tone5
pick
pig2
pig
pig_nose
pill
pineapple
ping_pong
pisces
pizza
place_of_worship
play_pause
point_down
point_down_tone1
point_down_tone2
point_down_tone3
point_down_tone4
point_down_tone5
point_left
point_left_tone1
point_left_tone2
point_left_tone3
point_left_tone4
point_left_tone5
point_right
point_right_tone1
point_right_tone2
point_right_tone3
point_right_tone4
point_right_tone5
point_up
point_up_2
point_up_2_tone1
point_up_2_tone2
point_up_2_tone3
point_up_2_tone4
point_up_2_tone5
point_up_tone1
point_up_tone2
point_up_tone3
point_up_tone4
point_up_tone5
police_car
poodle
poop
popcorn
post_office
postal_horn
postbox
potable_water
potato
pouch
poultry_leg
pound
pouting_cat
pray
pray_tone1
pray_tone2
pray_tone3
pray_tone4
pray_tone5
prayer_beads
pregnant_woman
pregnant_woman_tone1
pregnant_woman_tone2
pregnant_woman_tone3
pregnant_woman_tone4
pregnant_woman_tone5
prince
prince_tone1
prince_tone2
prince_tone3
prince_tone4
prince_tone5
princess
princess_tone1
princess_tone2
princess_tone3
princess_tone4
princess_tone5
printer
projector
punch
punch_tone1
punch_tone2
punch_tone3
punch_tone4
punch_tone5
purple_heart
purse
pushpin
put_litter_in_its_place
question
rabbit2
rabbit
race_car
racehorse
radio
radio_button
radioactive
rage
railway_car
railway_track
rainbow
rainbow_flag
raised_back_of_hand
raised_back_of_hand_tone1
raised_back_of_hand_tone2
raised_back_of_hand_tone3
raised_back_of_hand_tone4
raised_back_of_hand_tone5
raised_hand
raised_hand_tone1
raised_hand_tone2
raised_hand_tone3
raised_hand_tone4
raised_hand_tone5
raised_hands
raised_hands_tone1
raised_hands_tone2
raised_hands_tone3
raised_hands_tone4
raised_hands_tone5
raising_hand
raising_hand_tone1
raising_hand_tone2
raising_hand_tone3
raising_hand_tone4
raising_hand_tone5
ram
ramen
rat
record_button
recycle
red_car
red_circle
regional_indicator_a
regional_indicator_b
regional_indicator_c
regional_indicator_d
regional_indicator_e
regional_indicator_f
regional_indicator_g
regional_indicator_h
regional_indicator_i
regional_indicator_j
regional_indicator_k
regional_indicator_l
regional_indicator_m
regional_indicator_n
regional_indicator_o
regional_indicator_p
regional_indicator_q
regional_indicator_r
regional_indicator_s
regional_indicator_t
regional_indicator_u
regional_indicator_v
regional_indicator_w
regional_indicator_x
regional_indicator_y
regional_indicator_z
registered
relaxed
relieved
reminder_ribbon
repeat
repeat_one
restroom
revolving_hearts
rewind
rhino
ribbon
rice
rice_ball
rice_cracker
rice_scene
right_facing_fist
right_facing_fist_tone1
right_facing_fist_tone2
right_facing_fist_tone3
right_facing_fist_tone4
right_facing_fist_tone5
ring
robot
rocket
rofl
roller_coaster
rolling_eyes
rooster
rose
rosette
rotating_light
round_pushpin
rowboat
rowboat_tone1
rowboat_tone2
rowboat_tone3
rowboat_tone4
rowboat_tone5
rugby_football
runner
runner_tone1
runner_tone2
runner_tone3
runner_tone4
runner_tone5
running_shirt_with_sash
sa
sagittarius
sailboat
sake
salad
sandal
santa
santa_tone1
santa_tone2
santa_tone3
santa_tone4
santa_tone5
satellite
satellite_orbital
saxophone
scales
school
school_satchel
scissors
scooter
scorpion
scorpius
scream
scream_cat
scroll
seat
second_place
secret
see_no_evil
seedling
selfie
selfie_tone1
selfie_tone2
selfie_tone3
selfie_tone4
selfie_tone5
seven
shallow_pan_of_food
shamrock
shark
shaved_ice
sheep
shell
shield
shinto_shrine
ship
shirt
shopping_bags
shopping_cart
shower
shrimp
shrug
shrug_tone1
shrug_tone2
shrug_tone3
shrug_tone4
shrug_tone5
signal_strength
six
six_pointed_star
ski
skier
skull
skull_crossbones
sleeping
sleeping_accommodation
sleepy
slight_frown
slight_smile
slot_machine
small_blue_diamond
small_orange_diamond
small_red_triangle
small_red_triangle_down
smile
smile_cat
smiley
smiley_cat
smiling_imp
smirk
smirk_cat
smoking
snail
snake
sneezing_face
snowboarder
snowflake
snowman2
snowman
sob
soccer
soon
sos
sound
space_invader
spades
spaghetti
sparkle
sparkler
sparkles
sparkling_heart
speak_no_evil
speaker
speaking_head
speech_balloon
speech_left
speedboat
spider
spider_web
spoon
spy
spy_tone1
spy_tone2
spy_tone3
spy_tone4
spy_tone5
squid
stadium
star2
star
star_and_crescent
star_of_david
stars
station
statue_of_liberty
steam_locomotive
stew
stop_button
stopwatch
straight_ruler
strawberry
stuck_out_tongue
stuck_out_tongue_closed_eyes
stuck_out_tongue_winking_eye
stuffed_flatbread
sun_with_face
sunflower
sunglasses
sunny
sunrise
sunrise_over_mountains
surfer
surfer_tone1
surfer_tone2
surfer_tone3
surfer_tone4
surfer_tone5
sushi
suspension_railway
sweat
sweat_drops
sweat_smile
sweet_potato
swimmer
swimmer_tone1
swimmer_tone2
swimmer_tone3
swimmer_tone4
swimmer_tone5
symbols
synagogue
syringe
taco
tada
tanabata_tree
tangerine
taurus
taxi
tea
telephone
telephone_receiver
telescope
tennis
tent
thermometer
thermometer_face
thinking
third_place
thought_balloon
three
thumbsdown
thumbsdown_tone1
thumbsdown_tone2
thumbsdown_tone3
thumbsdown_tone4
thumbsdown_tone5
thumbsup
thumbsup_tone1
thumbsup_tone2
thumbsup_tone3
thumbsup_tone4
thumbsup_tone5
thunder_cloud_rain
ticket
tickets
tiger2
tiger
timer
tired_face
tm
toilet
tokyo_tower
tomato
tone1
tone2
tone3
tone4
tone5
tongue
tools
top
tophat
track_next
track_previous
trackball
tractor
traffic_light
train2
train
tram
triangular_flag_on_post
triangular_ruler
trident
triumph
trolleybus
trophy
tropical_drink
tropical_fish
truck
trumpet
tulip
tumbler_glass
turkey
turtle
tv
twisted_rightwards_arrows
two
two_hearts
two_men_holding_hands
two_women_holding_hands
u5272
u5408
u55b6
u6307
u6708
u6709
u6e80
u7121
u7533
u7981
u7a7a
umbrella2
umbrella
unamused
underage
unicorn
unlock
up
upside_down
urn
v
v_tone1
v_tone2
v_tone3
v_tone4
v_tone5
vertical_traffic_light
vhs
vibration_mode
video_camera
video_game
violin
virgo
volcano
volleyball
vs
vulcan
vulcan_tone1
vulcan_tone2
vulcan_tone3
vulcan_tone4
vulcan_tone5
walking
walking_tone1
walking_tone2
walking_tone3
walking_tone4
walking_tone5
waning_crescent_moon
waning_gibbous_moon
warning
wastebasket
watch
water_buffalo
water_polo
water_polo_tone1
water_polo_tone2
water_polo_tone3
water_polo_tone4
water_polo_tone5
watermelon
wave
wave_tone1
wave_tone2
wave_tone3
wave_tone4
wave_tone5
wavy_dash
waxing_crescent_moon
waxing_gibbous_moon
wc
weary
wedding
whale2
whale
wheel_of_dharma
wheelchair
white_check_mark
white_circle
white_flower
white_large_square
white_medium_small_square
white_medium_square
white_small_square
white_square_button
white_sun_cloud
white_sun_rain_cloud
white_sun_small_cloud
wilted_rose
wind_blowing_face
wind_chime
wine_glass
wink
wolf
woman
woman_tone1
woman_tone2
woman_tone3
woman_tone4
woman_tone5
womans_clothes
womans_hat
womens
worried
wrench
wrestlers
wrestlers_tone1
wrestlers_tone2
wrestlers_tone3
wrestlers_tone4
wrestlers_tone5
writing_hand
writing_hand_tone1
writing_hand_tone2
writing_hand_tone3
writing_hand_tone4
writing_hand_tone5
x
yellow_heart
yen
yin_yang
yum
zap
zero
zipper_mouth
zzz